@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -150,7 +150,7 @@
 #  define MIN_BLOCKING_BYTES_sparse       2048
 #  define MIN_BLOCKING_RECS_sparse        1
 
-#  define MIN_BLOCKING_BYTES_compressed   32768
+#  define MIN_BLOCKING_BYTES_compressed   65536
 #  define MIN_BLOCKING_RECS_compressed    1
 #else
 #  if defined(linux)
@@ -160,7 +160,7 @@
 #    define MIN_BLOCKING_BYTES_sparse       16384
 #    define MIN_BLOCKING_RECS_sparse        1
 
-#    define MIN_BLOCKING_BYTES_compressed   32768
+#    define MIN_BLOCKING_BYTES_compressed   65536
 #    define MIN_BLOCKING_RECS_compressed    1
 #  else
 #    define MIN_BLOCKING_BYTES_standard     1024
@@ -169,7 +169,7 @@
 #    define MIN_BLOCKING_BYTES_sparse       4096
 #    define MIN_BLOCKING_RECS_sparse        1
 
-#    define MIN_BLOCKING_BYTES_compressed   32768
+#    define MIN_BLOCKING_BYTES_compressed   65536
 #    define MIN_BLOCKING_RECS_compressed    1
 #  endif
 #endif
@@ -241,23 +241,23 @@
 * The default pad values for each data type.
 *****************************************************************************/
 
-#define DEFAULT_BYTE_PADVALUE           -127
-#define DEFAULT_INT1_PADVALUE           -127
-#define DEFAULT_UINT1_PADVALUE          254
-#define DEFAULT_INT2_PADVALUE           -32767
-#define DEFAULT_UINT2_PADVALUE          65534
-#define DEFAULT_INT4_PADVALUE           -2147483647
-#define DEFAULT_INT8_PADVALUE           -9223372036854775807LL
-#define DEFAULT_UINT4_PADVALUE          4294967294u
-#define DEFAULT_REAL4_PADVALUE          -1.0E30
-#define DEFAULT_FLOAT_PADVALUE          -1.0E30
+#define DEFAULT_BYTE_PADVALUE           (-127)
+#define DEFAULT_INT1_PADVALUE           (-127)
+#define DEFAULT_UINT1_PADVALUE          ((unsigned char)254)
+#define DEFAULT_INT2_PADVALUE           ((short)-32767)
+#define DEFAULT_UINT2_PADVALUE          ((unsigned short)65534)
+#define DEFAULT_INT4_PADVALUE           (-2147483647L)
+#define DEFAULT_INT8_PADVALUE           ((long long)-9223372036854775807LL)
+#define DEFAULT_UINT4_PADVALUE          (4294967294U)
+#define DEFAULT_REAL4_PADVALUE          ((float)-1.0E30f)
+#define DEFAULT_FLOAT_PADVALUE          ((float)-1.0E30f)
 #define DEFAULT_REAL8_PADVALUE          -1.0E30
 #define DEFAULT_DOUBLE_PADVALUE         -1.0E30
 #define DEFAULT_CHAR_PADVALUE           ' '
 #define DEFAULT_UCHAR_PADVALUE          ' '
 #define DEFAULT_EPOCH_PADVALUE          0.0
 #define DEFAULT_EPOCH16_PADVALUE        0.0
-#define DEFAULT_TT2000_PADVALUE         -9223372036854775807LL
+#define DEFAULT_TT2000_PADVALUE         ((long long)-9223372036854775807LL)
                                         /* 0000-01-01T00:00:00.000000000 */
 /*****************************************************************************
 * By default, convert -0.0 to 0.0 when read from or written to a CDF by the
