@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -53,6 +53,7 @@
 #define NOHEADERqual	8
 #define RECORDRANGEqual 9
 #define COL2ROWqual    10
+#define DETECTqual     11
 
 #define ALLDUMP         0
 #define DATADUMP        1
@@ -88,7 +89,7 @@ extern long startingRec, endingRec;
 ******************************************************************************/
 
 Logical DumpCDF PROTOARGs((int argC, char *argV[]));
-void QuitCDF PROTOARGs((char *text, CDFstatus status, char *msg));
+void QuitCDF PROTOARGs((char *file, char *text, CDFstatus status, char *msg));
 
 /*****************************************************************************/
 
