@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -762,8 +762,8 @@ STATICforIDL CDFstatus CompressGZIP_64 PROTOARGs((
   Int32 level
 ));
 STATICforIDL CDFstatus DecompressGZIP_64 PROTOARGs((
-  vFILE *srcFp, OFF_T srcOffset, CDFstatus srcError, vFILE *destFp,
-  OFF_T destOffset, CDFstatus destError
+  vFILE *srcFp, OFF_T srcOffset, OFF_T srcSize, CDFstatus srcError,
+  vFILE *destFp, OFF_T destOffset, CDFstatus destError
 ));
 STATICforIDL CDFstatus WriteVarValues64 PROTOARGs((
   struct CDFstruct *CDF, struct VarStruct *Var, Int32 recNum, Int32 offset,
