@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                    Header file for CDFmerge.
 *
@@ -62,7 +67,7 @@ void GetOutputFileName (char *);
 void GetOutputFileName2 (char *);
 void GetDataTimeStamp (char *);
 void BreakFields (char *, int, char **, int);
-void LoadgAttributes (CDFid);
+void LoadgAttributes (CDFid, int);
 void LoadgAttributes2 ();
 Logical LoadMasterTextFile (char *);
 Logical LoadMasterTextFile2 (char *);
