@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                        CDF `open' operations.
 *
@@ -24,6 +29,8 @@
 *   V3.2  17-Jun-07, D Berger   Added setting of Cur->cdf and id prior to calls
 *                               to ReadGDR in support of READONLY perfomance
 *                               improvement changes.
+*   V3.3  16-Jul-08, M Liu      Added ValidateCDF/ValidateCDF64 function calls
+*                               after GDR is read.
 *
 ******************************************************************************/
 
@@ -74,7 +81,7 @@ switch (Va->item) {
     MakeUpperString (CDFnameT);
 #endif
     RemoveCDFFileExtension(CDFnameT, CDFnameTx);
-    if (!ValidCDFname(CDFnameTx)) return BAD_CDF_NAME;
+/*  if (!ValidCDFname(CDFnameTx)) return BAD_CDF_NAME; */
     if (!sX(FindCDF(CDFnameTx,&no_append,
 		    &upper_case_ext,
 		    &version_numbers),&pStatus)) return pStatus;
@@ -84,18 +91,11 @@ switch (Va->item) {
     BuildFilePath (CDFt, CDFnameTx, no_append, upper_case_ext, version_numbers,
 		   INT32_ZERO, CDFnameX);
     if (!sX(CheckLFS(CDFnameX, &largeFile, NULL),&pStatus)) return pStatus; 
-
     if (!largeFile)
       dotFp = V_open (CDFnameX, READ_ONLY_a_mode);
     else
       dotFp = V_open64 (CDFnameX, READ_ONLY_a_mode);
     if (dotFp == NULL) return CDF_OPEN_ERROR;
-/*
-    if (dotFp->length > 0) 
-      largeFile = FALSE;
-    else
-      largeFile = TRUE;
-*/
     /**************************************************************************
     * Read the magic numbers.
     **************************************************************************/
@@ -136,7 +136,6 @@ switch (Va->item) {
       case V3magicNUMBER_1:
 	switch (magicNumber2) {
 	  case V2magicNUMBER_2u: /* Same as V3magicNUMBER_2u */
-/*	  case V3magicNUMBER_2u: */
 	    if (magicNumber1 == V2magicNUMBER_1) { /* 32-offset */
 	      if (!CACHEv(dotFp,NUMcacheUNKNOWN)) {
 	        V_close (dotFp, NULL, NULL);
@@ -151,7 +150,6 @@ switch (Va->item) {
 	    uDotFp = NULL;
 	    break;
 	  case V2magicNUMBER_2c:
-/*	  case V3magicNUMBER_2c: */
 	    uDotFp = V_scratch (ScratchDirectory(NULL), "cdf");
 	    if (uDotFp == NULL) {
 	      V_close (dotFp, NULL, NULL);
@@ -194,12 +192,17 @@ switch (Va->item) {
           V_close (dotFp, NULL, NULL);
         else
           V_close64 (dotFp, NULL, NULL);
-	return NOT_A_CDF_OR_NOT_SUPPORTED;
+        if (magicNumber1 == netCDFmagicNUMBER1 || 
+            magicNumber1 == netCDFmagicNUMBER2)
+          return IS_A_NETCDF;
+        else
+	  return NOT_A_CDF_OR_NOT_SUPPORTED;
     }
     /**************************************************************************
     * Allocate and begin initializing CDF structure.
     **************************************************************************/
-    CDF = (struct CDFstruct *) cdf_AllocateMemory (sizeof(struct CDFstruct), NULL);
+    CDF = (struct CDFstruct *) cdf_AllocateMemory (
+					(size_t)sizeof(struct CDFstruct), NULL);
     if (CDF == NULL) {
       if (!largeFile) {
         V_close (dotFp, NULL, NULL);
@@ -210,7 +213,8 @@ switch (Va->item) {
       } 
       return BAD_MALLOC;
     }
-    CDF->CDFname = (char *) cdf_AllocateMemory (strlen(CDFnameTx) + 1, NULL);
+    CDF->CDFname = (char *) cdf_AllocateMemory (
+					(size_t)strlen(CDFnameTx) + 1, NULL);
     if (CDF->CDFname == NULL) {
       if (!largeFile) {
         V_close (dotFp, NULL, NULL);
@@ -279,11 +283,10 @@ switch (Va->item) {
       Cur->cdf = CDF;
       *id = CDF;
       if (!sX(ReadGDR(CDF->fp,CDF->GDRoffset,
+		      GDR_EOF,&(CDF->eof),
 		      GDR_NrVARS,&(CDF->NrVars),
 		      GDR_NzVARS,&(CDF->NzVars),
 		      GDR_rMAXREC,&(CDF->rMaxRec),
-		      GDR_rNUMDIMS,&(CDF->rNumDims),
-		      GDR_rDIMSIZES,CDF->rDimSizes,
 		      GDR_NULL),&pStatus)) {
         AbortAccess (CDF, noUPDATE, noDELETE);
         cdf_FreeMemory (CDF, NULL);
@@ -313,6 +316,7 @@ switch (Va->item) {
         *id = (CDFid) NULL;
         return pStatus;
       }
+
       /************************************************************************
        * Set state info for use in ReadGDR - required by changes to support
        * READONLY performance enhancement.
@@ -320,11 +324,10 @@ switch (Va->item) {
       Cur->cdf = CDF;
       *id = CDF;
       if (!sX(ReadGDR64(CDF->fp,CDF->GDRoffset64,
+			GDR_EOF,&(CDF->eof64),
                         GDR_NrVARS,&(CDF->NrVars),
                         GDR_NzVARS,&(CDF->NzVars),
                         GDR_rMAXREC,&(CDF->rMaxRec),
-                        GDR_rNUMDIMS,&(CDF->rNumDims),
-                        GDR_rDIMSIZES,CDF->rDimSizes,
                         GDR_NULL),&pStatus)) {
         AbortAccess64 (CDF, noUPDATE, noDELETE);
         cdf_FreeMemory (CDF, NULL);
@@ -338,14 +341,87 @@ switch (Va->item) {
     **************************************************************************/
     CDF->singleFile = SINGLEfileBITset (CDRflags);
     CDF->rowMajor = ROWmajorBITset (CDRflags);
-    CDF->checksum = (PriorTo("3.2.0",version,release,increment) ?
-                     NO_CHECKSUM : ChecksumMethod (CDRflags));
+    CDF->checksum = (PriorTo("3.0.0",version,release,increment) ?
+                     NO_CHECKSUM : CDFChecksumMethod (CDRflags));
     CDF->fakeEPOCH = PriorTo("2.1.1",version,release,increment);
     CDF->wastedSpace = PriorTo("2.5",version,release,increment);
     CDF->badEOF = PriorTo("2.1",version,release,increment);
     CDF->badTerminatingOffsets = PriorTo("2.1",version,release,increment);
     CDF->assumedScopes = PriorTo("2.5",version,release,increment);
     CDF->workingCacheSize = BOO(CDF->singleFile,NUMcacheSINGLE,NUMcacheMULTI);
+    /************************************************************************
+     * Validate the CDF to make sure that certain data fields are normal by
+     * doing some sanity checks.
+     ***********************************************************************/
+    if (CDFgetValidate()) {
+      Logical debug;
+      if (CDFgetValidateDebug())
+        debug = TRUE;
+      else
+        debug = FALSE;
+      if (!largeFile) {
+        pStatus = ValidateCDF(CDF,CDF->fp,CDF->CDRoffset,CDF->eof, debug);
+        if (pStatus != CDF_OK) {
+          AbortAccess (CDF, noUPDATE, noDELETE);
+          cdf_FreeMemory (CDF, NULL);
+          Cur->cdf = NULL;
+          *id = (CDFid) NULL;
+          return pStatus;
+        }   
+      } else {
+        pStatus = ValidateCDF64(CDF,CDF->fp,CDF->CDRoffset64,CDF->eof64, debug);
+        if (pStatus != CDF_OK) {
+          AbortAccess64 (CDF, noUPDATE, noDELETE);
+          cdf_FreeMemory (CDF, NULL);
+          Cur->cdf = NULL;
+          *id = (CDFid) NULL;
+          if (pStatus == CORRUPTED_V3_CDF) {
+            char vri[6];
+            long libver, librel, libinc;
+            CDFstatus status;
+            snprintf (vri, (size_t) 6, "%1.1d.%1.1d.%1.1d", (int) version,
+                      (int) release, (int) increment);
+            status = CDFlib (GET_, LIB_VERSION_, &libver,
+                                   LIB_RELEASE_, &librel,
+                                   LIB_INCREMENT_, &libinc,
+                             NULL_);
+            if (PriorTo (vri, (Int32) libver, (Int32) librel, (Int32) libinc))
+              return UNABLE_TO_PROCESS_CDF;
+            else
+              return pStatus;
+          } else
+            return pStatus;
+        }
+      }
+    }
+    /**************************************************************************
+    * Acquire some more info from the CDF.
+    **************************************************************************/
+    if (!largeFile) {
+      CDF->CDRoffset = V2_CDR_OFFSET;
+      if (!sX(ReadGDR(CDF->fp,CDF->GDRoffset,
+                      GDR_rNUMDIMS,&(CDF->rNumDims),
+                      GDR_rDIMSIZES,CDF->rDimSizes,
+                      GDR_NULL),&pStatus)) {
+        AbortAccess (CDF, noUPDATE, noDELETE);
+        cdf_FreeMemory (CDF, NULL);
+        Cur->cdf = NULL;
+        *id = (CDFid) NULL;
+        return pStatus;
+      }
+    } else {
+      CDF->CDRoffset64 = (OFF_T) V3_CDR_OFFSET64;
+      if (!sX(ReadGDR64(CDF->fp,CDF->GDRoffset64,
+                        GDR_rNUMDIMS,&(CDF->rNumDims),
+                        GDR_rDIMSIZES,CDF->rDimSizes,
+                        GDR_NULL),&pStatus)) {
+        AbortAccess64 (CDF, noUPDATE, noDELETE);
+        cdf_FreeMemory (CDF, NULL);
+        Cur->cdf = NULL;
+        *id = (CDFid) NULL;
+        return pStatus;
+      }
+    }
     /**************************************************************************
     * Set the cache size for the "working" dotCDF file based on the format
     * of the CDF.
@@ -429,16 +505,18 @@ switch (Va->item) {
     Cur->cdf = CDF;
     *id = CDF;
     if (CDF->singleFile && CDF->checksum != NO_CHECKSUM) {
-      if (!sX(CDFconfirmChecksum(*id),&pStatus)) return pStatus; 
-/*
-    } else {
-      int ev = CDFgetChecksumEnvVar();
-      if (CDF->checksum == NO_CHECKSUM && ev > 0) {
-        if (!sX(CDFsetChecksum(*id, (long) ev),&pStatus)) return pStatus;
+      if (!sX(CDFconfirmChecksum(*id),&pStatus)) {
+        if (!largeFile) 
+          AbortAccess (CDF, noUPDATE, noDELETE);
+	else
+	  AbortAccess64 (CDF, noUPDATE, noDELETE);
+        cdf_FreeMemory (CDF, NULL);
+        Cur->cdf = NULL;
+        *id = (CDFid) NULL;
+        return pStatus;
       }
-*/
     }
-
+    AddOpenCDFsCount();
     break;
   }
   /****************************************************************************
