@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                    CDF `put' operations, part 2.
 *
@@ -525,7 +530,7 @@ switch (Va->item) {
     /**************************************************************************
     * Only apply to Version 2.6 and later CDFs.
     **************************************************************************/
-    if ((version*10+release) < 26) return CHECKSUM_NOT_ALLOWED;
+    if ((version*100+release) < 206) return CHECKSUM_NOT_ALLOWED;
 
     /**************************************************************************
     * Get write access.
@@ -561,7 +566,7 @@ switch (Va->item) {
   case rVAR_SPARSERECORDS_:
   case zVAR_SPARSERECORDS_: {
     Logical zOp = (Va->item == zVAR_SPARSERECORDS_), zVar;
-    Int32 VDRoffset, maxAllocated, maxRec;
+    Int32 VDRoffset, maxAllocated, maxRec, flags;
     struct CDFstruct *CDF; struct VarStruct *Var;
     Int32 sRecordsType = (Int32) va_arg (Va->ap, long);
     /**************************************************************************
@@ -606,6 +611,7 @@ switch (Va->item) {
     **************************************************************************/
     if (!sX(ReadVDR(CDF,CDF->fp,VDRoffset,zVar,
 			VDR_MAXREC,&maxRec,
+			VDR_FLAGS,&flags,
 			VDR_NULL),&pStatus)) {
       AbortAccess (CDF, UPDATE, noDELETE);
       return pStatus;
@@ -616,6 +622,8 @@ switch (Va->item) {
       return pStatus;
     }
     if (maxAllocated > NO_RECORD) return CANNOT_SPARSERECORDS;
+    if (!RECvaryBITset(flags) && sRecordsType != NO_SPARSERECORDS)
+      return CANNOT_SPARSERECORDS;
     /**************************************************************************
     * Based on type of sparseness...
     **************************************************************************/
