@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF				Get CDF status code explanation text.
 *
@@ -35,7 +40,7 @@ char *copyRight;
   strcpyX (copyRight,
 "\012\
 Common Data Format (CDF)\012\
-(C) Copyright 1990-2012 NASA/GSFC\012\
+(C) Copyright 1990-2014 NASA/GSFC\012\
 Space Physics Data Facility\012\
 NASA/Goddard Space Flight Center\012\
 Greenbelt, Maryland 20771 USA\012\
@@ -750,13 +755,17 @@ strcpyX (textPtr,
 CDF_STATUSTEXT_LEN);
 break;
 
-/*
-case ZLIB_COMPRESSION_ERROR:
+case ZLIB_COMPRESS_ERROR:
 strcpyX (textPtr,
-"ZLIB_COMPRESSION_ERROR: Error during Zlib compression/decompressing.",
+"ZLIB_ERROR: Error during ZLIB compression.",
+CDF_STATUSTEXT_LEN);
+break;
+
+case ZLIB_UNCOMPRESS_ERROR:
+strcpyX (textPtr,
+"ZLIB_ERROR: Error during ZLIB decompression.",
 CDF_STATUSTEXT_LEN);
 break;
-*/
 
 case ILLEGAL_EPOCH_FIELD:
 strcpyX (textPtr,
@@ -764,6 +773,12 @@ strcpyX (textPtr,
 CDF_STATUSTEXT_LEN);
 break;
 
+case CANNOT_INSERT_RECORDS:
+strcpyX (textPtr,
+"CANNOT_INSERT_RECORDS: Cannot insert records to a variable with sparserecords.",
+CDF_STATUSTEXT_LEN);
+break;
+
 default:
 snprintf (textPtr, (size_t) CDF_STATUSTEXT_LEN+1,
           "Text not found - unknown CDF status code (%ld).", status);
