@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -34,9 +34,9 @@
 #define HOURinNanoSecs          3600000000000LL
 #define MINUTEinNanoSecs        60000000000LL
 #define T12hinNanoSecs          43200000000000LL
-/* Julian days for 1707-09-23 and 2292-04-09, the valid TT2000 range. */
-#define JDY17070923             2344794
-#define JDY22920409             2558295
+/* Julian days for 1707-09-22 and 2292-04-11, the valid TT2000 range. */
+#define JDY17070922             2344793
+#define JDY22920411             2558297
 
 /* Number of Delta(dAT) expressions before leap seconds were introduced */
 #define NERA1 14
@@ -193,9 +193,9 @@ static int ValidateYMD (long yy, long mm, long dd)
 {
   double jday;
   if (yy <= 0 || mm < 0 || dd < 0) return 0;
-  /* Y-M-D should be in the 1707-09-23 and 2292-04-09 range. */
+  /* Y-M-D should be in the 1707-09-22 and 2292-04-11 range. */
   jday = JulianDay12h(yy, mm, dd);
-  if (jday < JDY17070923 || jday > JDY22920409) return 0;
+  if (jday < JDY17070922 || jday > JDY22920411) return 0;
   return 1; 
 }
 
@@ -533,11 +533,18 @@ va_dcl
     --secSinceJ2000;
   }
 */
-  secSinceJ2000 = (long) ((double)nanoSecSinceJ2000/SECinNanoSecsD);
-  nansec = (long) (nanoSecSinceJ2000 - secSinceJ2000 * SECinNanoSecs);
-  secSinceJ2000 += 43200; /* secs in T12hinNanoSecs */
-  secSinceJ2000 -= 32; /* secs in dTinNanoSecs */
-  nansec -= 184000000L; /* nanosec in dTinNanoSecs */
+  if (nanoSecSinceJ2000 > 0) { /* try to avoid overflow (substraction first) */
+    secSinceJ2000 = (long) ((double)nanoSecSinceJ2000/SECinNanoSecsD);
+    nansec = (long) (nanoSecSinceJ2000 - secSinceJ2000 * SECinNanoSecs);
+    secSinceJ2000 -= 32; /* secs portion in dT */
+    secSinceJ2000 += 43200; /* secs in 12h */
+    nansec -= 184000000L; /* nanosecs portion in dT */
+  } else { /* try to avoid underflow (addition first) */
+    nanoSecSinceJ2000 += T12hinNanoSecs; /* 12h in nanosecs */
+    nanoSecSinceJ2000 -= dTinNanoSecs /* dT in nanosecs */;
+    secSinceJ2000 = (long) ((double)nanoSecSinceJ2000/SECinNanoSecsD);
+    nansec = (long) (nanoSecSinceJ2000 - secSinceJ2000 * SECinNanoSecs);
+  }
   if (nansec < 0) {
     nansec = SECinNanoSecs + nansec;
     --secSinceJ2000;
@@ -911,7 +918,6 @@ va_dcl
   else if (lyl == 0 && lml == 1 && ldl == 1 && lhl == 0 && lnl == 0 &&
            lsl == 0 && lll == 0 && lul == 0 && lal == 0)
     return DEFAULT_TT2000_PADVALUE;
-/*  if ((yy-lyl) != 0.0 || (mm-lml) != 0.0) return ILLEGAL_TT2000_VALUE; */
   if (!YearWithin(lyl) && !ValidateYMD(lyl,lml,ldl))
     return ILLEGAL_TT2000_VALUE;
   iy = 10000000 * lml + 10000 * ldl + lyl;
@@ -924,12 +930,17 @@ va_dcl
   jd = jd - JulianDateJ2000_12h;
   subDayinNanoSecs = lhl * HOURinNanoSecs + lnl * MINUTEinNanoSecs +
                      lsl * SECinNanoSecs + lll * 1000000 + lul * 1000 + lal;
-  nanoSecSinceJ2000 = (long long) (jd * DAYinNanoSecs) + subDayinNanoSecs;
+  nanoSecSinceJ2000 = (long long) jd * DAYinNanoSecs + subDayinNanoSecs;
   t2 = (long long) (currentLeapSeconds * SECinNanoSecs);
-  if (nanoSecSinceJ2000 < 0)
-    nanoSecSinceJ2000 = nanoSecSinceJ2000 + t2 + dTinNanoSecs - T12hinNanoSecs;
-  else
-    nanoSecSinceJ2000 = nanoSecSinceJ2000 - T12hinNanoSecs + t2 + dTinNanoSecs;
+  if (nanoSecSinceJ2000 < 0) {
+    nanoSecSinceJ2000 += t2;
+    nanoSecSinceJ2000 += dTinNanoSecs;
+    nanoSecSinceJ2000 -= T12hinNanoSecs;
+  } else {
+    nanoSecSinceJ2000 -= T12hinNanoSecs;
+    nanoSecSinceJ2000 += t2;
+    nanoSecSinceJ2000 += dTinNanoSecs;
+  }
   return nanoSecSinceJ2000;
 }
 
