@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -80,7 +80,7 @@ STATICforIDL CDFstatus ValidateCDF (struct CDFstruct *CDF, vFILE *CDFfp,
      * Read record size.
      *************************************************************************/
      offset = V_tell (CDFfp);
-     if (!CDF->badEOF && offset >= fileSize) break;
+     if (!CDF->badEOF && offset == fileSize) break;
      if (!Read32(CDFfp,&recordSize)) {
        if (!CDF->badEOF) return CRE;
        else break;
