@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                     Validate internal records in a CDF V3.* file.
 *
@@ -26,7 +31,8 @@
 * Local function prototypes.
 ******************************************************************************/
 
-static CDFstatus QuitCDF PROTOARGs((char *why, int size, int num, void *value1, void *value2, Logical debug));
+static CDFstatus QuitCDF PROTOARGs((char *why, OFF_T offset, int size, int num,
+void *value1, void *value2, Logical debug));
 static CDFstatus ValidateCCR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
 static CDFstatus ValidateCDR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
 static CDFstatus ValidateGDR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
@@ -71,10 +77,10 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
      * Read record size.
      *************************************************************************/
      offset = V_tell64 (CDFfp);
-     if (offset >= fileSize64) break;
+     if (offset == fileSize64) break;
      if (!Read64_64(CDFfp,&recordSize)) return CRE;
      if (recordSize < 1 || recordSize > fileSize64) 
-       return QuitCDF ("CDF: an invalid internal record size ",
+       return QuitCDF ("CDF: an invalid internal record size ", offset,
                        8, 1, &recordSize, 0, debug);
      /*************************************************************************
      * Read record type.
@@ -162,7 +168,7 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
           status = ValidateVVR (CDFfp, offset, debug);
           if (status != CDF_OK) return status;
           if (recordSize < VVR_BASE_SIZE64) 
-            return QuitCDF ("CDF: record size is invalid ",
+            return QuitCDF ("CDF(VVR): record size is invalid ", offset,
                             8, 1, &recordSize, 0, debug);
           offset = offset + recordSize;
           if (!SEEKv64(CDFfp,offset,vSEEK_SET)) return CRE;
@@ -206,7 +212,7 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
         * Illegal record type.
         **********************************************************************/
         default: {
-	    return QuitCDF ("CDF: an invalid internal record type",
+	    return QuitCDF ("CDF: an invalid internal record type", offset,
                             4, 1, &recordType, 0, debug);
         }
      }
@@ -215,7 +221,7 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
   * Check attribute links and their attribute entries.
   ****************************************************************************/
   if (GDR.NumAttr != numAttrs)
-    return QuitCDF ("CDF: number of attributes does not match: ",
+    return QuitCDF ("CDF: number of attributes does not match: ", (OFF_T) -1,
                     4, 2, &GDR.NumAttr, &numAttrs, debug);
   if (numAttrs > 0) {
     status = ValidateAttributeLinks(CDF, CDFfp, debug);
@@ -225,7 +231,7 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
   * Check rVariable links and their data.
   ****************************************************************************/
   if (GDR.NrVars != rVars)
-    return QuitCDF ("CDF: number of rVariables does not match: ",
+    return QuitCDF ("CDF: number of rVariables does not match: ", (OFF_T) -1,
                     4, 2, &GDR.NrVars, &rVars, debug);
   if (rVars > 0) {
     status = ValidateVariableLinks(CDF, CDFfp, FALSE, debug);
@@ -235,7 +241,7 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
   * Check zVariable links and their data.
   ****************************************************************************/
   if (GDR.NzVars != zVars)
-    return QuitCDF ("CDF: number of zVariables does not match: ",
+    return QuitCDF ("CDF: number of zVariables does not match: ", (OFF_T) -1,
                     4, 2, &GDR.NzVars, &zVars, debug);
   if (zVars > 0) {
     status = ValidateVariableLinks(CDF, CDFfp, TRUE, debug);
@@ -265,20 +271,20 @@ CDFstatus ValidateCDR (vFILE *fp, OFF_T offset, Logical debug)
                       CDR_NULL);
   if (status != CDF_OK) return status;
   if (CDR.RecordType != CDR_) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF: record type is invalid ", offset,
                     4, 1, &(CDR.RecordType), 0, debug);
   if (CDR.RecordSize < CDR_BASE_SIZE64 ||
       CDR.RecordSize > CDR_MAX_SIZE64) 
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF: record size is invalid ", offset,
                     8, 1, &(CDR.RecordSize), 0, debug);
   if (CDR.GDRoffset < 1) 
-    return QuitCDF ("CDF: offset to GDR is invalid ",
+    return QuitCDF ("CDF: offset to GDR is invalid ", offset,
                     8, 1, &(CDR.GDRoffset), 0, debug);
   if (CDR.Version != 3) 
-    return QuitCDF ("CDF: version number is invalid ",
+    return QuitCDF ("CDF: version number is invalid ", offset,
                     4, 1, &(CDR.Version), 0, debug);
   if (!ValidEncoding(CDR.Encoding,&actualEncoding)) 
-    return QuitCDF ("CDF: encoding is invalid ",
+    return QuitCDF ("CDF: encoding is invalid ", offset,
                     4, 1, &(CDR.Encoding), 0, debug);
   return CDF_OK;
 }
@@ -303,33 +309,33 @@ CDFstatus ValidateGDR (vFILE *fp, OFF_T offset, Logical debug)
                       GDR_NULL);
   if (status != CDF_OK) return status;
   if (GDR.RecordType != GDR_) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(GDR): record type is invalid ", offset,
                     4, 1, &(GDR.RecordType), 0, debug);
   if (GDR.RecordSize < GDR_BASE_SIZE64 ||
       GDR.RecordSize > GDR_MAX_SIZE64) 
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(GDR): record size is invalid ", offset,
                     8, 1, &(GDR.RecordSize), 0, debug);
   if (GDR.NrVars < 0 || (GDR.NrVars > 0 && GDR.rVDRhead < 1)) 
-    return QuitCDF ("CDF: NrVars or their link is invalid ",
+    return QuitCDF ("CDF(GDR): NrVars or their link is invalid ", offset,
                     4, 1, &(GDR.NrVars), 0, debug);
   if (GDR.NumAttr < 0 || (GDR.NumAttr > 0 && GDR.ADRhead < 1)) 
-    return QuitCDF ("CDF: number of attributes or their link is invalid ",
+    return QuitCDF ("CDF(GDR): number of attributes or their link is invalid ", offset,
                     4, 1, &(GDR.NumAttr), 0, debug);
   if (GDR.rMaxRec < -1) 
-    return QuitCDF ("CDF: max rVars record is invalid ",
+    return QuitCDF ("CDF(GDR): max rVars record is invalid ", offset,
                     4, 1, &(GDR.rMaxRec), 0, debug);
   if (GDR.rNumDims < 0 || GDR.rNumDims > CDF_MAX_DIMS) 
-    return QuitCDF ("CDF: number of dimensions for rVars is invalid ",
+    return QuitCDF ("CDF(GDR): number of dimensions for rVars is invalid ", offset,
                     4, 1, &(GDR.rNumDims), 0, debug);
   if (GDR.NzVars < 0 || (GDR.NzVars > 0 && GDR.zVDRhead < 1)) 
-    return QuitCDF ("CDF: NzVars or their link is invalid ",
+    return QuitCDF ("CDF(GDR): NzVars or their link is invalid ", offset,
                     4, 1, &(GDR.NzVars), 0, debug);
   if (GDR.UIRhead < 0) 
-    return QuitCDF ("CDF: offset to UIR is invalid ",
+    return QuitCDF ("CDF(GDR): offset to UIR is invalid ", offset,
                     8, 1, &(GDR.UIRhead), 0, debug);
   for (i = 0; i < (int)GDR.rNumDims; ++i)
     if (GDR.rDimSizes[i] < 1) 
-    return QuitCDF ("CDF: dimensional size is invalid ",
+    return QuitCDF ("CDF(GDR): dimensional size is invalid ", offset,
                     4, 1, &(GDR.rDimSizes[i]), 0, debug);
   return CDF_OK;
 }
@@ -355,41 +361,41 @@ CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
                       ADR_NULL);
   if (status != CDF_OK) return status;
   if (ADR.RecordType != ADR_) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(ADR): record type is invalid ", offset,
                     4, 1, &(ADR.RecordType), 0, debug);
   if (ADR.RecordSize < ADR_BASE_SIZE64 ||
       ADR.RecordSize > ADR_MAX_SIZE64) 
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(ADR): record size is invalid ", offset,
                     8, 1, &(ADR.RecordSize), 0, debug);
   if (ADR.ADRnext < 0 || ((ADR.Num < (GDR.NumAttr-1))  && ADR.ADRnext == 0)) 
-    return QuitCDF ("CDF: offset to next ADR is invalid ",
+    return QuitCDF ("CDF(ADR): offset to next ADR is invalid ", offset,
                     8, 1, &(ADR.ADRnext), 0, debug);
   if (ADR.AgrEDRhead < 0 || (ADR.NgrEntries > 0 && ADR.AgrEDRhead == 0)) 
-    return QuitCDF ("CDF: offset to AgrEDR is invalid ",
+    return QuitCDF ("CDF(ADR): offset to AgrEDR is invalid ", offset,
                     8, 1, &(ADR.AgrEDRhead), 0, debug);
   if (!ValidAttrScope(ADR.Scope)) 
-    return QuitCDF ("CDF: scope is invalid ",
+    return QuitCDF ("CDF(ADR): scope is invalid ", offset,
                     4, 1, &(ADR.Scope), 0, debug);
   if (ADR.Num < 0 || ADR.Num > GDR.NumAttr) 
-    return QuitCDF ("CDF: attribute number is invalid ",
+    return QuitCDF ("CDF(ADR): attribute number is invalid ", offset,
                     4, 2, &(ADR.Num), &(GDR.NumAttr), debug);
   if (ADR.NgrEntries < 0) 
-    return QuitCDF ("CDF: number of g/rEntries is invalid ",
+    return QuitCDF ("CDF(ADR): number of g/rEntries is invalid ", offset,
                     4, 1, &(ADR.NgrEntries), 0, debug);
   if (ADR.MAXgrEntry < -1) 
-    return QuitCDF ("CDF: max g/rEntry is invalid ",
+    return QuitCDF ("CDF(ADR): max g/rEntry is invalid ", offset,
                     4, 1, &(ADR.MAXgrEntry), 0, debug);
   if ((ADR.Scope == VARIABLE_SCOPE) && (ADR.MAXgrEntry < (ADR.NgrEntries-1)))
-    return QuitCDF ("CDF: max rEntry is invalid ",
+    return QuitCDF ("CDF(ADR): max rEntry is invalid ", offset,
                     4, 2, &(ADR.MAXgrEntry), &(ADR.NgrEntries), debug);
   if (ADR.AzEDRhead < 0 || (ADR.NzEntries > 0 && ADR.AzEDRhead == 0)) 
-    return QuitCDF ("CDF: offset to next AzEDR is invalid ",
+    return QuitCDF ("CDF(ADR): offset to next AzEDR is invalid ", offset,
                     8, 1, &(ADR.AzEDRhead), 0, debug);
   if ((ADR.Scope == VARIABLE_SCOPE) && (ADR.MAXzEntry < (ADR.NzEntries-1)))
-    return QuitCDF ("CDF: max zEntry is invalid ",
+    return QuitCDF ("CDF(ADR): max zEntry is invalid ", offset,
                     4, 2, &(ADR.MAXzEntry), &(ADR.NzEntries), debug);
   if (!ValidAttrName(ADR.Name)) 
-    return QuitCDF ("CDF: attribute name is invalid ", 
+    return QuitCDF ("CDF(ADR): attribute name is invalid ",  offset,
                     0, 1, ADR.Name, 0, debug);
   return CDF_OK;
 }
@@ -418,42 +424,42 @@ CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
   if (status != CDF_OK) return status;
   if ((!zEntry && AEDR.RecordType != AgrEDR_) || 
       (zEntry && AEDR.RecordType != AzEDR_)) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(AEDR): record type is invalid ", offset,
                     4, 1, &(AEDR.RecordType), 0, debug);
   if (AEDR.RecordSize < AEDR_BASE_SIZE64) 
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(AEDR): record size is invalid ", offset,
                     8, 1, &(AEDR.RecordSize), 0, debug);
   if (AEDR.AEDRnext < 0) 
-    return QuitCDF ("CDF: offset to next AEDR is invalid ",
+    return QuitCDF ("CDF(AEDR): offset to next AEDR is invalid ", offset,
                     8, 1, &(AEDR.AEDRnext), 0, debug);
 /*  Check for "AEDR.AttrNum != num" is not included as some CDFs fail this
     check. Don't know why.... */
 /*
   if (AEDR.AttrNum < 0 || AEDR.AttrNum > GDR.NumAttr) 
-    return QuitCDF ("CDF: attribute number is invalid ",
+    return QuitCDF ("CDF(AEDR): attribute number is invalid ", offset,
                     4, 2, &(AEDR.AttrNum), &(GDR.NumAttr), debug);
 */
   if (!ValidDataType(AEDR.DataType)) 
-    return QuitCDF ("CDF: data type is invalid ",
+    return QuitCDF ("CDF(AEDR): data type is invalid ", offset,
                     4, 1, &(AEDR.DataType), 0, debug);
   if (AEDR.Num < 0 || AEDR.Num > maxEntry)
-    return QuitCDF ("CDF: entry number is invalid ",
+    return QuitCDF ("CDF(AEDR): entry number is invalid ", offset,
                     4, 2, &(AEDR.Num), &(maxEntry), debug);
   if (AEDR.AEDRnext < 0)
-    return QuitCDF ("CDF: next AEDR offset is invalid : ",
+    return QuitCDF ("CDF(AEDR): next AEDR offset is invalid : ", offset,
                     8, 1, &(AEDR.AEDRnext), 0, debug);
   if (AEDR.NumElems < 1 || 
       (STRINGdataType(AEDR.DataType) && 
        AEDR.NumElems > (AEDR.RecordSize - AEDR_VALUE_OFFSET64))) 
-    return QuitCDF ("CDF: number of elements is invalid ",
+    return QuitCDF ("CDF(AEDR): number of elements is invalid ", offset,
                     4, 1, &(AEDR.NumElems), 0, debug);
   nBytes = (size_t) (CDFelemSize(AEDR.DataType) * AEDR.NumElems);
   if (nBytes < 1 || 
       nBytes > (AEDR.RecordSize - AEDR_VALUE_OFFSET64)) 
-    return QuitCDF ("CDF: entry value size is invalid ",
+    return QuitCDF ("CDF(AEDR): entry value size is invalid ", offset,
                     4, 1, &nBytes, 0, debug);	
   if (AEDR.RecordSize > (AEDR_MAX_SIZE64 + nBytes))
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(AEDR): record size is invalid ", offset,
                     8, 1, &(AEDR.RecordSize), 0, debug);
   return CDF_OK;
 }
@@ -483,52 +489,52 @@ CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
                       VDR_NULL);
   if (status != CDF_OK) return status;
   if ((zVar && VDR.RecordType != zVDR_) || (!zVar && VDR.RecordType != rVDR_)) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(VDR): record type is invalid ", offset,
                     4, 1, &(VDR.RecordType), 0, debug);
   if (VDR.RecordSize < (zVar ? zVDR_BASE_SIZE64 : rVDR_BASE_SIZE64))
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(VDR): record size is invalid ", offset,
                     8, 1, &(VDR.RecordSize), 0, debug);
   if (!ValidDataType(VDR.DataType)) 
-    return QuitCDF ("CDF: data type is invalid ",
+    return QuitCDF ("CDF(VDR): data type is invalid ", offset,
                     4, 1, &(VDR.DataType), 0, debug);
   if (VDR.MaxRec < -1) 
-    return QuitCDF ("CDF: max record is invalid ",
+    return QuitCDF ("CDF(VDR): max record is invalid ", offset,
                     4, 1, &(VDR.MaxRec), 0, debug);
   if (VDR.NumElems < 1 || (!STRINGdataType(VDR.DataType) && VDR.NumElems != 1))
-    return QuitCDF ("CDF: number of elements is invalid ",
+    return QuitCDF ("CDF(VDR): number of elements is invalid ", offset,
                     4, 1, &(VDR.NumElems), 0, debug);
   if (zVar) numVars = CDF->NzVars;
   else numVars = CDF->NrVars;
   if (VDR.Num < 0 || VDR.Num > numVars)
-    return QuitCDF ("CDF: variable number is invalid ",
+    return QuitCDF ("CDF(VDR): variable number is invalid ", offset,
                     4, 2, &(VDR.Num), &numVars, debug);
   if ((VDR.Num < (numVars-1)) && (VDR.VDRnext < 1))
-    return QuitCDF ("CDF: offset to next VDR is invalid ",
+    return QuitCDF ("CDF(VDR): offset to next VDR is invalid ", offset,
                     8, 1, &(VDR.VDRnext), 0, debug);
   if (VARcompressionBITset(VDR.Flags) && VDR.CPRorSPRoffset <= NO_OFFSET64) 
-    return QuitCDF ("CDF: offset to CPRorSPR is invalid ",
+    return QuitCDF ("CDF(VDR): offset to CPRorSPR is invalid ", offset,
                     8, 1, &(VDR.CPRorSPRoffset), 0, debug);
   if (VDR.blockingFactor < 0) 
-    return QuitCDF ("CDF: blocking factor is invalid ",
+    return QuitCDF ("CDF(VDR): blocking factor is invalid ", offset,
                     4, 1, &(VDR.blockingFactor), 0, debug);
   if (!ValidVarName(VDR.Name)) 
-    return QuitCDF ("CDF: variable name is invalid ", 
+    return QuitCDF ("CDF(VDR): variable name is invalid ",  offset,
                     0, 1, VDR.Name, 0, debug);
   if (zVar) {
     if (VDR.zNumDims < 0 || VDR.zNumDims > CDF_MAX_DIMS) 
-    return QuitCDF ("CDF: number of dimensions is invalid ",
+    return QuitCDF ("CDF(VDR): number of dimensions is invalid ", offset,
                     4, 1, &(VDR.zNumDims), 0, debug);
     for (ix = 0; ix < (int)VDR.zNumDims; ++ix)
       if (VDR.zDimSizes[ix] < 1) 
-    return QuitCDF ("CDF: dimensional size is invalid ",
+    return QuitCDF ("CDF(VDR): dimensional size is invalid ", offset,
                     4, 1, &(VDR.zDimSizes[ix]), 0, debug);
   }
   nBytes = (size_t) (CDFelemSize(VDR.DataType)*VDR.NumElems);
   if (nBytes < 1)
-    return QuitCDF ("CDF: pad value size is invalid ",
+    return QuitCDF ("CDF(VDR): pad value size is invalid ", offset,
                     4, 1, &nBytes, 0, debug);
   if (VDR.RecordSize > ((zVar ? zVDR_MAX_SIZE64 : rVDR_MAX_SIZE64) + nBytes))
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(VDR): record size is invalid ", offset,
                     8, 1, &(VDR.RecordSize), 0, debug);
   return CDF_OK;
 }
@@ -555,39 +561,39 @@ CDFstatus ValidateVXR (vFILE *fp, OFF_T offset, Int32 lastRec, Logical debug)
                       VXR_NULL);
   if (status != CDF_OK) return status;
   if (VXR.RecordType != VXR_) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(VXR): record type is invalid ", offset,
                     4, 1, &(VXR.RecordType), 0, debug);
   if (VXR.RecordSize != (VXR_FIRSTREC_OFFSET64 + 16 * VXR.Nentries))
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(VXR): record size is invalid ", offset,
                     8, 1, &(VXR.RecordSize), 0, debug);
   if (VXR.Nentries < 0 || VXR.Nentries > MAX_VXR_ENTRIES) 
-    return QuitCDF ("CDF: number of entries is invalid ",
+    return QuitCDF ("CDF(VXR): number of entries is invalid ", offset,
                     4, 1, &(VXR.Nentries), 0, debug); 
   if (VXR.NusedEntries < 0 || VXR.NusedEntries > VXR.Nentries) 
-    return QuitCDF ("CDF: number of used entries is invalid ",
+    return QuitCDF ("CDF(VXR): number of used entries is invalid ", offset,
                     4, 2, &(VXR.NusedEntries), &(VXR.Nentries), debug);
   if (VXR.VXRnext > 0) {
     if (VXR.Last[VXR.NusedEntries-1] > lastRec)
-      return QuitCDF ("CDF: a variable last record does not match in a Variable Index Record: ",
+      return QuitCDF ("CDF(VXR): a variable last record does not match in a Variable Index Record: ", offset,
                       4, 2, &(VXR.Last[VXR.NusedEntries-1]), &lastRec, debug);
     status = ValidateVXR (fp, VXR.VXRnext, lastRec, debug);
     if (status != CDF_OK) return status;
   } else if (VXR.VXRnext < 0) {
-      return QuitCDF ("CDF: a link offset to next record is negative in a Variable Index Record: ",
+      return QuitCDF ("CDF(VXR): a link offset to next record is negative in a Variable Index Record: ", offset,
                       8, 1, &(VXR.VXRnext), 0, debug);
   }
 
   for (i = 0; i < VXR.NusedEntries; ++i) {
     if (VXR.First[i] < 0 || VXR.Last[i] < 0 || VXR.First[i] > VXR.Last[i])
-      return QuitCDF ("CDF: entry value for first/last is invalid ",
+      return QuitCDF ("CDF(VXR): entry value for first/last is invalid ", offset,
                       4, 2, &(VXR.First[i]), &(VXR.Last[i]), debug);
     if (VXR.Offset[i] < 1) 
-      return QuitCDF ("CDF: entry offset is invalid ",
+      return QuitCDF ("CDF(VXR): entry offset is invalid ", offset,
                       8, 1, &(VXR.Offset[i]), 0, debug);
     status = ReadIrType64 (fp, VXR.Offset[i], &irType);
     if (status != CDF_OK) return status;
     if (irType != VXR_ && irType != VVR_ && irType != CVVR_)
-      return QuitCDF ("CDF: entry value for offset is invalid ",
+      return QuitCDF ("CDF(VXR): entry value for offset is invalid ", offset,
                       8, 1, &(VXR.Offset[i]), 0, debug);
     if (irType == VXR_ && VXR.Offset[i] != offset) {
       status = ValidateVXR (fp, VXR.Offset[i], lastRec, debug);
@@ -617,10 +623,10 @@ CDFstatus ValidateVVR (vFILE *fp, OFF_T offset, Logical debug)
                       VVR_NULL);
   if (status != CDF_OK) return status;
   if (VVR.RecordType != VVR_) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(VVR): record type is invalid ", offset,
                     4, 1, &(VVR.RecordType), 0, debug);
   if (VVR.RecordSize < VVR_BASE_SIZE64) 
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(VVR): record size is invalid ", offset,
                     8, 1, &(VVR.RecordSize), 0, debug);
   return CDF_OK;
 }
@@ -645,16 +651,16 @@ CDFstatus ValidateUIR (vFILE *fp, OFF_T offset, Logical debug)
                       UIR_NULL);  
   if (status != CDF_OK) return status;
   if (UIR.RecordType != UIR_) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(UIR): record type is invalid ", offset,
                     4, 1, &(UIR.RecordType), 0, debug);
   if (UIR.RecordSize < UIR_BASE_SIZE64) 
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(UIR): record size is invalid ", offset,
                     8, 1, &(UIR.RecordSize), 0, debug);
   if (UIR.NextUIR < 0) 
-    return QuitCDF ("CDF: offset to next UIR is invalid ",
+    return QuitCDF ("CDF(UIR): offset to next UIR is invalid ", offset,
                     8, 1, &(UIR.NextUIR), 0, debug);
   if (UIR.PrevUIR < 0) 
-    return QuitCDF ("CDF: offset to previous UIR is invalid ",
+    return QuitCDF ("CDF(UIR): offset to previous UIR is invalid ", offset,
                     8, 1, &(UIR.PrevUIR), 0, debug);
   return CDF_OK;
 }
@@ -679,16 +685,16 @@ CDFstatus ValidateCCR (vFILE *fp, OFF_T offset, Logical debug)
                       CCR_NULL);
   if (status != CDF_OK) return status;
   if (CCR.RecordType != CCR_) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(CCR): record type is invalid ", offset,
                     4, 1, &(CCR.RecordType), 0, debug);
   if (CCR.RecordSize < CCR_BASE_SIZE64) 
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(CCR): record size is invalid ", offset,
                     8, 1, &(CCR.RecordSize), 0, debug);
   if (CCR.uSize < 0) 
-    return QuitCDF ("CDF: uncompressed file size is invalid ",
+    return QuitCDF ("CDF(CCR): uncompressed file size is invalid ", offset,
                     8, 1, &(CCR.uSize), 0, debug);
   if (CCR.CPRoffset < 0) 
-    return QuitCDF ("CDF: offset to CPR is invalid ",
+    return QuitCDF ("CDF(CCR): offset to CPR is invalid ", offset,
                     8, 1, &(CCR.CPRoffset), 0, debug);
   return CDF_OK;
 }
@@ -715,18 +721,18 @@ CDFstatus ValidateCPR (vFILE *fp, OFF_T offset, Logical debug)
                       CPR_NULL);
   if (status != CDF_OK) return status;
   if (CPR.RecordType != CPR_) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(CPR): record type is invalid ", offset,
                     4, 1, &(CPR.RecordType), 0, debug);
   if (CPR.RecordSize != (CPR_BASE_SIZE64 + CPR.pCount * sizeof(Int32)))
-    return QuitCDF ("CDF: reocrd size is invalid ",
+    return QuitCDF ("CDF(CPR): reocrd size is invalid ", offset,
                     8, 1, &(CPR.RecordSize), 0, debug);
   if (CPR.pCount != 1) 
-    return QuitCDF ("CDF: compression parameter count is invalid ",
+    return QuitCDF ("CDF(CPR): compression parameter count is invalid ", offset,
                     4, 1, &(CPR.pCount), 0, debug);
   cType = (long) CPR.cType;
   cParms[0] = (long) CPR.cParms[0];
   if (ValidateCompression64(cType, cParms) != CDF_OK) 
-    return QuitCDF ("CDF: compression parameter is invalid ",
+    return QuitCDF ("CDF(CPR): compression parameter is invalid ", offset,
                     4, 1, &(CPR.cType), 0, debug);
   return CDF_OK;
 }
@@ -752,13 +758,13 @@ CDFstatus ValidateSPR (vFILE *fp, OFF_T offset, Logical debug)
                       SPR_NULL);
   if (status != CDF_OK) return status;
   if (SPR.RecordType != SPR_) 
-    return QuitCDF ("CDF: record type is invalid ",
+    return QuitCDF ("CDF(SPR): record type is invalid ", offset,
                     4, 1, &(SPR.RecordType), 0, debug);
   if (SPR.RecordSize != (SPR_BASE_SIZE64 + SPR.pCount * sizeof(Int32)))
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(SPR): record size is invalid ", offset,
                     8, 1, &(SPR.RecordSize), 0, debug);
   if (SPR.pCount < 1 || SPR.pCount > CDF_MAX_PARMS) 
-    return QuitCDF ("CDF: sparseness parameter count is invalid ",
+    return QuitCDF ("CDF(SPR): sparseness parameter count is invalid ", offset,
                     4, 1, &(SPR.pCount), 0, debug);
   return CDF_OK;
 }
@@ -783,10 +789,10 @@ CDFstatus ValidateCVVR (vFILE *fp, OFF_T offset, Logical debug)
                        CVVR_NULL);
   if (status != CDF_OK) return status;
   if (CVVR.RecordSize < CVVR_BASE_SIZE64) 
-    return QuitCDF ("CDF: record size is invalid ",
+    return QuitCDF ("CDF(CVVR): record size is invalid ", offset,
                     8, 1, &(CVVR.RecordSize), 0, debug);
   if (CVVR.cSize < 0) 
-    return QuitCDF ("CDF: uncompressed records size is invalid ",
+    return QuitCDF ("CDF(CVVR): uncompressed records size is invalid ", offset,
                     8, 1, &(CVVR.cSize), 0, debug);
   return CDF_OK;
 }
@@ -803,7 +809,7 @@ CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
   Int32 num, numgrEntries, maxgrEntry, numzEntries, maxzEntry, scope;
   int ix, *visit;
 
-  visit = (int *) cdf_AllocateMemory (GDR.NumAttr * sizeof(Int32), NULL);
+  visit = (int *) cdf_AllocateMemory ((size_t)GDR.NumAttr * sizeof(Int32), NULL);
   if (visit == NULL) return BAD_MALLOC;
   for (ix = 0; ix < GDR.NumAttr; ++ix) visit[ix] = 0;
   offset = GDR.ADRhead;
@@ -845,7 +851,7 @@ CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
   for (ix = 0; ix < GDR.NumAttr; ++ix) {
     if (visit[ix] == 0) {
       cdf_FreeMemory (visit, NULL);
-      return QuitCDF ("CDF: an attribute unreachable in attribute link: ",
+      return QuitCDF ("CDF: an attribute unreachable in attribute link: ", (OFF_T) -1,
                       4, 1, &ix, 0, debug);
     }
   }
@@ -869,7 +875,7 @@ CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
   
   offset = EDRhead;
   lastNum = 0;
-  visits = (Int32 *) cdf_AllocateMemory (numEntries * sizeof(Int32), NULL);
+  visits = (Int32 *) cdf_AllocateMemory ((size_t)numEntries * sizeof(Int32), NULL);
   if (visits == NULL) return BAD_MALLOC;
   for (ix = 0; ix < numEntries; ++ix) visits[ix] = 0;
   ix = 0;
@@ -887,14 +893,14 @@ CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
       for (iy = 0; iy < ix; ++iy) {
         if (visits[iy] == entryNum) {
           cdf_FreeMemory (visits, NULL);
-          return QuitCDF ("CDF: entry number is repeating in an attribute entry link: ",
+          return QuitCDF ("CDF: entry number is repeating in an attribute entry link: ", (OFF_T) -1,
                           4, 1, &entryNum, 0, debug);
         }
       }
     }
     if (ix == (int) numEntries) {
       cdf_FreeMemory (visits, NULL);
-      return QuitCDF ("CDF: number of entries is more than maximum in an attribute entry link: ",
+      return QuitCDF ("CDF: number of entries is more than maximum in an attribute entry link: ", (OFF_T) -1,
                       4, 1, &ix, 0, debug);
     }
     visits[ix] = entryNum;
@@ -904,7 +910,7 @@ CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
   }
   if (lastNum != maxEntry) {
     cdf_FreeMemory (visits, NULL);
-    return QuitCDF ("CDF: last entry number is not the maximum entry number in  an attribute entry link: ",
+    return QuitCDF ("CDF: last entry number is not the maximum entry number in  an attribute entry link: ", (OFF_T) -1,
                     4, 2, &lastNum, &maxEntry, debug);
   }
   cdf_FreeMemory (visits, NULL);
@@ -924,13 +930,13 @@ CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
   int ix, numVars, *visit;
 
   numVars = (zVar ? GDR.NzVars : GDR.NrVars);
-  visit = (int *) malloc(numVars * sizeof(Int32));
+  visit = (int *) cdf_AllocateMemory(numVars * sizeof(Int32), NULL);
   for (ix = 0; ix < numVars; ++ix) visit[ix] = 0;
   offset = (zVar ? GDR.zVDRhead : GDR.rVDRhead);
   for (ix = 0; ix < numVars; ++ix) {
     status = ValidateVDR (CDF, fp, offset, zVar, debug);
     if (status != CDF_OK) {
-      free (visit);
+      cdf_FreeMemory (visit, NULL);
       return status;
     }
     status = ReadVDR64 (CDF, fp, offset, zVar,
@@ -945,14 +951,14 @@ CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
     if (CDF->singleFile && lastRec > -1) {
       status = ValidateVariableValueLinks (CDF, fp, lastRec, headVXR, debug);
       if (status != CDF_OK) {
-        free (visit);
+        cdf_FreeMemory (visit, NULL);
         return status;
       }
     }
     if (VARcompressionBITset(flags)) {
       status = ValidateCPR (fp, cprOffset, debug);
       if (status != CDF_OK) {
-        free (visit);
+        cdf_FreeMemory (visit, NULL);
         return status;
       }
     }
@@ -962,16 +968,16 @@ CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
 
   for (ix = 0; ix < numVars; ++ix) {
     if (visit[ix] == 0) {
-      free (visit);
+      cdf_FreeMemory (visit, NULL);
       if (zVar)
-        return QuitCDF ("CDF: a zVariable unreachable in the variable chain: ",
+        return QuitCDF ("CDF: a zVariable unreachable in the variable chain: ", (OFF_T) -1,
                         4, 1, &ix, 0, debug);
       else
-        return QuitCDF ("CDF: a rVariable unreachable in the variable chain: ",
+        return QuitCDF ("CDF: a rVariable unreachable in the variable chain: ", (OFF_T) -1,
                         4, 1, &ix, 0, debug);
     }
   }
-  free (visit);
+  cdf_FreeMemory (visit, NULL);
   if (offset != 0) {
     status = ReadVDR64 (CDF, fp, offset, zVar,
                         VDR_NUM, &num,
@@ -980,17 +986,17 @@ CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
     if (status == CDF_OK) {
       if (num >= numVars) { 
         if (zVar)
-          return QuitCDF ("CDF: a zVariable unreachable in the variable chain: ",
+          return QuitCDF ("CDF(VDR): a zVariable unreachable in the variable chain: ", offset,
                           4, 1, &num, 0, debug);
         else
-          return QuitCDF ("CDF: a rVariable unreachable in the variable chain: ",
+          return QuitCDF ("CDF(VDR): a rVariable unreachable in the variable chain: ", offset,
                           4, 1, &num, 0, debug);
       } else {
         if (zVar) 
-          return QuitCDF ("CDF: a zVariable is repeated in the variable chain: ",
+          return QuitCDF ("CDF(VDR): a zVariable is repeated in the variable chain: ", offset,
                           4, 1, &num, 0, debug);
         else
-          return QuitCDF ("CDF: a rVariable unreachable in the variable chain: ",
+          return QuitCDF ("CDF(VDR): a rVariable unreachable in the variable chain: ", offset,
                           4, 1, &num, 0, debug);
       }
     }
@@ -1017,28 +1023,38 @@ CDFstatus ValidateVariableValueLinks (struct CDFstruct *CDF, vFILE *fp,
 * QuitCDF.
 ******************************************************************************/
 
-CDFstatus QuitCDF (char *why, int isize, int num, void *value1, void *value2, 
-                   Logical debug)
+CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num, void *value1,
+		   void *value2, Logical debug)
 {
   
   if (debug) {
-    char text[101];
+    char text[151], texta[41];
     text[0] = NUL;
-    strcpyX (text, why, 100);
-    if (strlen(why) < 100) {
+    strcpyX (text, why, 150);
+    if (offset >= 0) {
+#if !defined(win32) && !defined(__MINGW32__)
+      snprintf (texta, (size_t) sizeof(texta),
+	        " (@%lld) ", offset);
+#else
+      snprintf (texta, (size_t) sizeof(texta),
+	        " (@%I64d) ", offset);
+#endif
+      strcatX (text, texta, 150);
+    }
+    if (strlen(why) < 150) {
       if (num == 2) { /* Two argument values to show. */
         if (isize == 4) { /* Each one is a 4-byte int type. */ 
                           /* Each int is up to 10 digits + sign. */
           char text2[2 * 11 + 6 + 1];
-          text2[0] = NUL;
+          text2[0] = (char) NUL;
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%ld vs %ld)", (long) *(int *)value1,
                     (long) *(int *)value2);
-          strcatX (text, text2, 100);
+          strcatX (text, text2, 150);
         } else if (isize == 8) { /* Each one is a 8-byte long long type. */
                                  /* Each long long is up to 19 digits + sign. */
           char text2[2 * 20 + 6 + 1];
-          text2[0] = NUL;
+          text2[0] = (char) NUL;
 #if !defined(win32) && !defined(__MINGW32__)
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%lld vs %lld)", *(OFF_T *)value1, *(OFF_T *)value2);
@@ -1046,29 +1062,29 @@ CDFstatus QuitCDF (char *why, int isize, int num, void *value1, void *value2,
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%I64d vs %I64d)", *(OFF_T *)value1, *(OFF_T *)value2);
 #endif
-          strcatX (text, text2, 100);
+          strcatX (text, text2, 150);
         } else { /* Each one is a string. */
           char *text2;
           size_t len = strlen ((char *) value1) + strlen ((char *) value2) + 6
                        + 1;
-          text2 = (char *) malloc (len);
+          text2 = (char *) cdf_AllocateMemory (len, NULL);
           if (text2 != NULL) {
-            text2[0] = NUL;
+            text2[0] = (char) NUL;
             snprintf (text2, len, "(%s vs %s)", (char *)value1, (char *)value2);
-            strcatX (text, text2, 100);
-            free (text2);
+            strcatX (text, text2, 150);
+            cdf_FreeMemory (text2, NULL);
           }
         }
       } else { /* Only one argument value to show. */
         if (isize == 4) { /* 4 extra chars are for 2 " ", "(", and ")". */
           char text2[11 + 2 + 1];
-          text2[0] = NUL;
+          text2[0] = (char) NUL;
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%ld)", (long) *(int *)value1);
-          strcatX (text, text2, 100);
+          strcatX (text, text2, 150);
         } else if (isize == 8) {
           char text2[20 + 2 + 1];
-          text2[0] = NUL;
+          text2[0] = (char) NUL;
 #if !defined(win32) && !defined(__MINGW32__)
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%lld)", *(OFF_T *)value1);
@@ -1076,16 +1092,16 @@ CDFstatus QuitCDF (char *why, int isize, int num, void *value1, void *value2,
           snprintf (text2, (size_t) sizeof(text2),
 		    "(%I64d)", *(OFF_T *)value1);
 #endif
-          strcatX (text, text2, 100);
+          strcatX (text, text2, 150);
         } else {
           char *text2;
           size_t len = strlen ((char *) value1)  + 2 + 1;
-          text2 = (char *) malloc (len);
+          text2 = (char *) cdf_AllocateMemory (len, NULL);
           if (text2 != NULL) {
-            text2[0] = NUL;
+            text2[0] = (char) NUL;
             snprintf (text2, len, "(%s)", (char *)value1);
-            strcatX (text, text2, 100);
-            free (text2);
+            strcatX (text, text2, 150);
+            cdf_FreeMemory (text2, NULL);
           }
         }
       }
