@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -698,9 +698,29 @@ va_dcl
 	   tOffset = offset + (OFF_T) (rVDR_PADVALUE_OFFSETb64 + 
                                        (rNumDims*sizeof(Int32)));
 	 }
-	 if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CWE;
-	 if (!sX(WriteBuffer64(CDF,fp,dataType,
+	 if (STRINGdataType(dataType)) {
+	   size_t len;
+	   len = strlen ((char *)padValue);
+	   if ((int)len >= numElems) {
+	          if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CWE;
+	          if (!sX(WriteBuffer64(CDF,fp,dataType,
 			       numElems,padValue),&pStatus)) return pStatus;
+	   } else {
+             int ix; char *newPad;
+	     newPad = (char *) cdf_AllocateMemory ((size_t) numElems, NULL);
+	     strncpy (newPad, (char *)padValue, len);
+	     for (ix = (int) len; ix < numElems; ++ix)
+		*(newPad+ix) = (char) ' ';
+	     if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CWE;
+	     if (!sX(WriteBuffer64(CDF,fp,dataType,
+		     numElems,newPad),&pStatus)) return pStatus;
+	     cdf_FreeMemory (newPad, NULL);
+	   }
+	 } else {
+	   if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CWE;
+	   if (!sX(WriteBuffer64(CDF,fp,dataType,
+			         numElems,padValue),&pStatus)) return pStatus;
+	 }
 	 break;
        }
        case VDR_RECORDSIZE:
