@@ -3,10 +3,9 @@
  * For conditions of distribution and use, see copyright notice in zlib.h
  */
 
-/* @(#) $Id: adler32.c,v 1.3 2012/11/15 18:03:43 liu Exp $ */
+/* @(#) $Id: adler32.c,v 1.1.1.1 2014/04/17 19:02:57 liu Exp $ */
 
 #include "zutil.h"
-#include <stdio.h>
 
 #define local static
 
@@ -63,13 +62,14 @@ local uLong adler32_combine_ OF((uLong adler1, uLong adler2, z_off64_t len2));
 #endif
 
 /* ========================================================================= */
-uLong ZEXPORT spdfadler32(adler, buf, len)
+uLong ZEXPORT adler32(adler, buf, len)
     uLong adler;
     const Bytef *buf;
     uInt len;
 {
     unsigned long sum2;
     unsigned n;
+
     /* split Adler-32 into component sums */
     sum2 = (adler >> 16) & 0xffff;
     adler &= 0xffff;
@@ -162,7 +162,7 @@ local uLong adler32_combine_(adler1, adler2, len2)
 }
 
 /* ========================================================================= */
-uLong ZEXPORT spdfadler32_combine(adler1, adler2, len2)
+uLong ZEXPORT adler32_combine(adler1, adler2, len2)
     uLong adler1;
     uLong adler2;
     z_off_t len2;
@@ -170,7 +170,7 @@ uLong ZEXPORT spdfadler32_combine(adler1, adler2, len2)
     return adler32_combine_(adler1, adler2, len2);
 }
 
-uLong ZEXPORT spdfadler32_combine64(adler1, adler2, len2)
+uLong ZEXPORT adler32_combine64(adler1, adler2, len2)
     uLong adler1;
     uLong adler2;
     z_off64_t len2;
