@@ -1,5 +1,5 @@
 /* deflate.c -- compress data using the deflation algorithm
- * Copyright (C) 1995-2012 Jean-loup Gailly and Mark Adler
+ * Copyright (C) 1995-2013 Jean-loup Gailly and Mark Adler
  * For conditions of distribution and use, see copyright notice in zlib.h
  */
 
@@ -47,12 +47,12 @@
  *
  */
 
-/* @(#) $Id: deflate.c,v 1.7 2013/07/22 14:45:29 liu Exp $ */
+/* @(#) $Id: deflate.c,v 1.1.1.1 2014/04/17 19:02:57 liu Exp $ */
 
 #include "deflate.h"
 
-const char spdfdeflate_copyright[] =
-   " deflate 1.2.7 Copyright 1995-2012 Jean-loup Gailly and Mark Adler ";
+const char deflate_copyright[] =
+   " deflate 1.2.8 Copyright 1995-2013 Jean-loup Gailly and Mark Adler ";
 /*
   If you use the zlib library in a product, an acknowledgment is welcome
   in the documentation of your product. If for some reason you cannot
@@ -198,19 +198,19 @@ struct static_tree_desc_s {int dummy;}; /* for buggy compilers */
     zmemzero((Bytef *)s->head, (unsigned)(s->hash_size-1)*sizeof(*s->head));
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflateInit_(strm, level, version, stream_size)
+int ZEXPORT deflateInit_(strm, level, version, stream_size)
     z_streamp strm;
     int level;
     const char *version;
     int stream_size;
 {
-    return spdfdeflateInit2_(strm, level, Z_DEFLATED, MAX_WBITS, DEF_MEM_LEVEL,
+    return deflateInit2_(strm, level, Z_DEFLATED, MAX_WBITS, DEF_MEM_LEVEL,
                          Z_DEFAULT_STRATEGY, version, stream_size);
     /* To do: ignore strm->next_in if we use it as window */
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflateInit2_(strm, level, method, windowBits, memLevel, strategy,
+int ZEXPORT deflateInit2_(strm, level, method, windowBits, memLevel, strategy,
                   version, stream_size)
     z_streamp strm;
     int  level;
@@ -229,6 +229,7 @@ int ZEXPORT spdfdeflateInit2_(strm, level, method, windowBits, memLevel, strateg
     /* We overlay pending_buf and d_buf+l_buf. This works since the average
      * output size for (length,distance) codes is <= 24 bits.
      */
+
     if (version == Z_NULL || version[0] != my_version[0] ||
         stream_size != sizeof(z_stream)) {
         return Z_VERSION_ERROR;
@@ -240,7 +241,7 @@ int ZEXPORT spdfdeflateInit2_(strm, level, method, windowBits, memLevel, strateg
 #ifdef Z_SOLO
         return Z_STREAM_ERROR;
 #else
-        strm->zalloc = spdfzcalloc;
+        strm->zalloc = zcalloc;
         strm->opaque = (voidpf)0;
 #endif
     }
@@ -248,7 +249,7 @@ int ZEXPORT spdfdeflateInit2_(strm, level, method, windowBits, memLevel, strateg
 #ifdef Z_SOLO
         return Z_STREAM_ERROR;
 #else
-        strm->zfree = spdfzcfree;
+        strm->zfree = zcfree;
 #endif
 
 #ifdef FASTEST
@@ -304,8 +305,8 @@ int ZEXPORT spdfdeflateInit2_(strm, level, method, windowBits, memLevel, strateg
     if (s->window == Z_NULL || s->prev == Z_NULL || s->head == Z_NULL ||
         s->pending_buf == Z_NULL) {
         s->status = FINISH_STATE;
-        strm->msg = (char*)ERR_MSG(Z_MEM_ERROR);
-        spdfdeflateEnd (strm);
+        strm->msg = ERR_MSG(Z_MEM_ERROR);
+        deflateEnd (strm);
         return Z_MEM_ERROR;
     }
     s->d_buf = overlay + s->lit_bufsize/sizeof(ush);
@@ -315,11 +316,11 @@ int ZEXPORT spdfdeflateInit2_(strm, level, method, windowBits, memLevel, strateg
     s->strategy = strategy;
     s->method = (Byte)method;
 
-    return spdfdeflateReset(strm);
+    return deflateReset(strm);
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflateSetDictionary (strm, dictionary, dictLength)
+int ZEXPORT deflateSetDictionary (strm, dictionary, dictLength)
     z_streamp strm;
     const Bytef *dictionary;
     uInt  dictLength;
@@ -328,7 +329,8 @@ int ZEXPORT spdfdeflateSetDictionary (strm, dictionary, dictLength)
     uInt str, n;
     int wrap;
     unsigned avail;
-    unsigned char *next;
+    z_const unsigned char *next;
+
     if (strm == Z_NULL || strm->state == Z_NULL || dictionary == Z_NULL)
         return Z_STREAM_ERROR;
     s = strm->state;
@@ -338,7 +340,7 @@ int ZEXPORT spdfdeflateSetDictionary (strm, dictionary, dictLength)
 
     /* when using zlib wrappers, compute Adler-32 for provided dictionary */
     if (wrap == 1)
-        strm->adler = spdfadler32(strm->adler, dictionary, dictLength);
+        strm->adler = adler32(strm->adler, dictionary, dictLength);
     s->wrap = 0;                    /* avoid computing Adler-32 in read_buf */
 
     /* if dictionary would fill window, just replace the history */
@@ -357,7 +359,7 @@ int ZEXPORT spdfdeflateSetDictionary (strm, dictionary, dictLength)
     avail = strm->avail_in;
     next = strm->next_in;
     strm->avail_in = dictLength;
-    strm->next_in = (Bytef *)dictionary;
+    strm->next_in = (z_const Bytef *)dictionary;
     fill_window(s);
     while (s->lookahead >= MIN_MATCH) {
         str = s->strstart;
@@ -387,10 +389,11 @@ int ZEXPORT spdfdeflateSetDictionary (strm, dictionary, dictLength)
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflateResetKeep (strm)
+int ZEXPORT deflateResetKeep (strm)
     z_streamp strm;
 {
     deflate_state *s;
+
     if (strm == Z_NULL || strm->state == Z_NULL ||
         strm->zalloc == (alloc_func)0 || strm->zfree == (free_func)0) {
         return Z_STREAM_ERROR;
@@ -410,27 +413,30 @@ int ZEXPORT spdfdeflateResetKeep (strm)
     s->status = s->wrap ? INIT_STATE : BUSY_STATE;
     strm->adler =
 #ifdef GZIP
-        s->wrap == 2 ? spdfcrc32(0L, Z_NULL, 0) :
+        s->wrap == 2 ? crc32(0L, Z_NULL, 0) :
 #endif
-        spdfadler32(0L, Z_NULL, 0);
+        adler32(0L, Z_NULL, 0);
     s->last_flush = Z_NO_FLUSH;
-    _spdf_tr_init(s);
+
+    _tr_init(s);
+
     return Z_OK;
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflateReset (strm)
+int ZEXPORT deflateReset (strm)
     z_streamp strm;
 {
     int ret;
-    ret = spdfdeflateResetKeep(strm);
+
+    ret = deflateResetKeep(strm);
     if (ret == Z_OK)
         lm_init(strm->state);
     return ret;
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflateSetHeader (strm, head)
+int ZEXPORT deflateSetHeader (strm, head)
     z_streamp strm;
     gz_headerp head;
 {
@@ -441,7 +447,7 @@ int ZEXPORT spdfdeflateSetHeader (strm, head)
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflatePending (strm, pending, bits)
+int ZEXPORT deflatePending (strm, pending, bits)
     unsigned *pending;
     int *bits;
     z_streamp strm;
@@ -455,13 +461,14 @@ int ZEXPORT spdfdeflatePending (strm, pending, bits)
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflatePrime (strm, bits, value)
+int ZEXPORT deflatePrime (strm, bits, value)
     z_streamp strm;
     int bits;
     int value;
 {
     deflate_state *s;
     int put;
+
     if (strm == Z_NULL || strm->state == Z_NULL) return Z_STREAM_ERROR;
     s = strm->state;
     if ((Bytef *)(s->d_buf) < s->pending_out + ((Buf_size + 7) >> 3))
@@ -472,7 +479,7 @@ int ZEXPORT spdfdeflatePrime (strm, bits, value)
             put = bits;
         s->bi_buf |= (ush)((value & ((1 << put) - 1)) << s->bi_valid);
         s->bi_valid += put;
-        _spdf_tr_flush_bits(s);
+        _tr_flush_bits(s);
         value >>= put;
         bits -= put;
     } while (bits);
@@ -480,7 +487,7 @@ int ZEXPORT spdfdeflatePrime (strm, bits, value)
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflateParams(strm, level, strategy)
+int ZEXPORT deflateParams(strm, level, strategy)
     z_streamp strm;
     int level;
     int strategy;
@@ -488,6 +495,7 @@ int ZEXPORT spdfdeflateParams(strm, level, strategy)
     deflate_state *s;
     compress_func func;
     int err = Z_OK;
+
     if (strm == Z_NULL || strm->state == Z_NULL) return Z_STREAM_ERROR;
     s = strm->state;
 
@@ -504,7 +512,9 @@ int ZEXPORT spdfdeflateParams(strm, level, strategy)
     if ((strategy != s->strategy || func != configuration_table[level].func) &&
         strm->total_in != 0) {
         /* Flush the last buffer: */
-        err = spdfdeflate(strm, Z_BLOCK);
+        err = deflate(strm, Z_BLOCK);
+        if (err == Z_BUF_ERROR && s->pending == 0)
+            err = Z_OK;
     }
     if (s->level != level) {
         s->level = level;
@@ -518,7 +528,7 @@ int ZEXPORT spdfdeflateParams(strm, level, strategy)
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflateTune(strm, good_length, max_lazy, nice_length, max_chain)
+int ZEXPORT deflateTune(strm, good_length, max_lazy, nice_length, max_chain)
     z_streamp strm;
     int good_length;
     int max_lazy;
@@ -553,13 +563,14 @@ int ZEXPORT spdfdeflateTune(strm, good_length, max_lazy, nice_length, max_chain)
  * upper bound of about 14% expansion does not seem onerous for output buffer
  * allocation.
  */
-uLong ZEXPORT spdfdeflateBound(strm, sourceLen)
+uLong ZEXPORT deflateBound(strm, sourceLen)
     z_streamp strm;
     uLong sourceLen;
 {
     deflate_state *s;
     uLong complen, wraplen;
     Bytef *str;
+
     /* conservative upper bound for compressed data */
     complen = sourceLen +
               ((sourceLen + 7) >> 3) + ((sourceLen + 63) >> 6) + 5;
@@ -634,7 +645,7 @@ local void flush_pending(strm)
     unsigned len;
     deflate_state *s = strm->state;
 
-    _spdf_tr_flush_bits(s);
+    _tr_flush_bits(s);
     len = s->pending;
     if (len > strm->avail_out) len = strm->avail_out;
     if (len == 0) return;
@@ -651,7 +662,7 @@ local void flush_pending(strm)
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflate (strm, flush)
+int ZEXPORT deflate (strm, flush)
     z_streamp strm;
     int flush;
 {
@@ -670,6 +681,7 @@ int ZEXPORT spdfdeflate (strm, flush)
         ERR_RETURN(strm, Z_STREAM_ERROR);
     }
     if (strm->avail_out == 0) ERR_RETURN(strm, Z_BUF_ERROR);
+
     s->strm = strm; /* just in case */
     old_flush = s->last_flush;
     s->last_flush = flush;
@@ -678,7 +690,7 @@ int ZEXPORT spdfdeflate (strm, flush)
     if (s->status == INIT_STATE) {
 #ifdef GZIP
         if (s->wrap == 2) {
-            strm->adler = spdfcrc32(0L, Z_NULL, 0);
+            strm->adler = crc32(0L, Z_NULL, 0);
             put_byte(s, 31);
             put_byte(s, 139);
             put_byte(s, 8);
@@ -714,7 +726,7 @@ int ZEXPORT spdfdeflate (strm, flush)
                     put_byte(s, (s->gzhead->extra_len >> 8) & 0xff);
                 }
                 if (s->gzhead->hcrc)
-                    strm->adler = spdfcrc32(strm->adler, s->pending_buf,
+                    strm->adler = crc32(strm->adler, s->pending_buf,
                                         s->pending);
                 s->gzindex = 0;
                 s->status = EXTRA_STATE;
@@ -746,7 +758,7 @@ int ZEXPORT spdfdeflate (strm, flush)
                 putShortMSB(s, (uInt)(strm->adler >> 16));
                 putShortMSB(s, (uInt)(strm->adler & 0xffff));
             }
-            strm->adler = spdfadler32(0L, Z_NULL, 0);
+            strm->adler = adler32(0L, Z_NULL, 0);
         }
     }
 #ifdef GZIP
@@ -757,7 +769,7 @@ int ZEXPORT spdfdeflate (strm, flush)
             while (s->gzindex < (s->gzhead->extra_len & 0xffff)) {
                 if (s->pending == s->pending_buf_size) {
                     if (s->gzhead->hcrc && s->pending > beg)
-                        strm->adler = spdfcrc32(strm->adler, s->pending_buf + beg,
+                        strm->adler = crc32(strm->adler, s->pending_buf + beg,
                                             s->pending - beg);
                     flush_pending(strm);
                     beg = s->pending;
@@ -768,7 +780,7 @@ int ZEXPORT spdfdeflate (strm, flush)
                 s->gzindex++;
             }
             if (s->gzhead->hcrc && s->pending > beg)
-                strm->adler = spdfcrc32(strm->adler, s->pending_buf + beg,
+                strm->adler = crc32(strm->adler, s->pending_buf + beg,
                                     s->pending - beg);
             if (s->gzindex == s->gzhead->extra_len) {
                 s->gzindex = 0;
@@ -786,7 +798,7 @@ int ZEXPORT spdfdeflate (strm, flush)
             do {
                 if (s->pending == s->pending_buf_size) {
                     if (s->gzhead->hcrc && s->pending > beg)
-                        strm->adler = spdfcrc32(strm->adler, s->pending_buf + beg,
+                        strm->adler = crc32(strm->adler, s->pending_buf + beg,
                                             s->pending - beg);
                     flush_pending(strm);
                     beg = s->pending;
@@ -799,7 +811,7 @@ int ZEXPORT spdfdeflate (strm, flush)
                 put_byte(s, val);
             } while (val != 0);
             if (s->gzhead->hcrc && s->pending > beg)
-                strm->adler = spdfcrc32(strm->adler, s->pending_buf + beg,
+                strm->adler = crc32(strm->adler, s->pending_buf + beg,
                                     s->pending - beg);
             if (val == 0) {
                 s->gzindex = 0;
@@ -817,7 +829,7 @@ int ZEXPORT spdfdeflate (strm, flush)
             do {
                 if (s->pending == s->pending_buf_size) {
                     if (s->gzhead->hcrc && s->pending > beg)
-                        strm->adler = spdfcrc32(strm->adler, s->pending_buf + beg,
+                        strm->adler = crc32(strm->adler, s->pending_buf + beg,
                                             s->pending - beg);
                     flush_pending(strm);
                     beg = s->pending;
@@ -830,7 +842,7 @@ int ZEXPORT spdfdeflate (strm, flush)
                 put_byte(s, val);
             } while (val != 0);
             if (s->gzhead->hcrc && s->pending > beg)
-                strm->adler = spdfcrc32(strm->adler, s->pending_buf + beg,
+                strm->adler = crc32(strm->adler, s->pending_buf + beg,
                                     s->pending - beg);
             if (val == 0)
                 s->status = HCRC_STATE;
@@ -845,7 +857,7 @@ int ZEXPORT spdfdeflate (strm, flush)
             if (s->pending + 2 <= s->pending_buf_size) {
                 put_byte(s, (Byte)(strm->adler & 0xff));
                 put_byte(s, (Byte)((strm->adler >> 8) & 0xff));
-                strm->adler = spdfcrc32(0L, Z_NULL, 0);
+                strm->adler = crc32(0L, Z_NULL, 0);
                 s->status = BUSY_STATE;
             }
         }
@@ -887,6 +899,7 @@ int ZEXPORT spdfdeflate (strm, flush)
     if (strm->avail_in != 0 || s->lookahead != 0 ||
         (flush != Z_NO_FLUSH && s->status != FINISH_STATE)) {
         block_state bstate;
+
         bstate = s->strategy == Z_HUFFMAN_ONLY ? deflate_huff(s, flush) :
                     (s->strategy == Z_RLE ? deflate_rle(s, flush) :
                         (*(configuration_table[s->level].func))(s, flush));
@@ -909,9 +922,9 @@ int ZEXPORT spdfdeflate (strm, flush)
         }
         if (bstate == block_done) {
             if (flush == Z_PARTIAL_FLUSH) {
-                _spdf_tr_align(s);
+                _tr_align(s);
             } else if (flush != Z_BLOCK) { /* FULL_FLUSH or SYNC_FLUSH */
-                _spdf_tr_stored_block(s, (char*)0, 0L, 0);
+                _tr_stored_block(s, (char*)0, 0L, 0);
                 /* For a full flush, this empty block will be recognized
                  * as a special marker by inflate_sync().
                  */
@@ -963,12 +976,13 @@ int ZEXPORT spdfdeflate (strm, flush)
 }
 
 /* ========================================================================= */
-int ZEXPORT spdfdeflateEnd (strm)
+int ZEXPORT deflateEnd (strm)
     z_streamp strm;
 {
     int status;
 
     if (strm == Z_NULL || strm->state == Z_NULL) return Z_STREAM_ERROR;
+
     status = strm->state->status;
     if (status != INIT_STATE &&
         status != EXTRA_STATE &&
@@ -997,7 +1011,7 @@ int ZEXPORT spdfdeflateEnd (strm)
  * To simplify the source, this is not supported for 16-bit MSDOS (which
  * doesn't have enough memory anyway to duplicate compression states).
  */
-int ZEXPORT spdfdeflateCopy (dest, source)
+int ZEXPORT deflateCopy (dest, source)
     z_streamp dest;
     z_streamp source;
 {
@@ -1008,6 +1022,7 @@ int ZEXPORT spdfdeflateCopy (dest, source)
     deflate_state *ss;
     ushf *overlay;
 
+
     if (source == Z_NULL || dest == Z_NULL || source->state == Z_NULL) {
         return Z_STREAM_ERROR;
     }
@@ -1030,7 +1045,7 @@ int ZEXPORT spdfdeflateCopy (dest, source)
 
     if (ds->window == Z_NULL || ds->prev == Z_NULL || ds->head == Z_NULL ||
         ds->pending_buf == Z_NULL) {
-        spdfdeflateEnd (dest);
+        deflateEnd (dest);
         return Z_MEM_ERROR;
     }
     /* following zmemcpy do not work for 16-bit MSDOS */
@@ -1072,11 +1087,11 @@ local int read_buf(strm, buf, size)
 
     zmemcpy(buf, strm->next_in, len);
     if (strm->state->wrap == 1) {
-        strm->adler = spdfadler32(strm->adler, buf, len);
+        strm->adler = adler32(strm->adler, buf, len);
     }
 #ifdef GZIP
     else if (strm->state->wrap == 2) {
-        strm->adler = spdfcrc32(strm->adler, buf, len);
+        strm->adler = crc32(strm->adler, buf, len);
     }
 #endif
     strm->next_in  += len;
@@ -1351,9 +1366,9 @@ local void check_match(s, start, match, length)
         do {
             fprintf(stderr, "%c%c", s->window[match++], s->window[start++]);
         } while (--length != 0);
-        spdf_error("invalid match");
+        z_error("invalid match");
     }
-    if (gz_verbose > 1) {
+    if (z_verbose > 1) {
         fprintf(stderr,"\\[%d,%d]", start-match, length);
         do { putc(s->window[start++], stderr); } while (--length != 0);
     }
@@ -1521,7 +1536,7 @@ local void fill_window(s)
  * IN assertion: strstart is set to the end of the current match.
  */
 #define FLUSH_BLOCK_ONLY(s, last) { \
-   _spdf_tr_flush_block(s, (s->block_start >= 0L ? \
+   _tr_flush_block(s, (s->block_start >= 0L ? \
                    (charf *)&s->window[(unsigned)s->block_start] : \
                    (charf *)Z_NULL), \
                 (ulg)((long)s->strstart - s->block_start), \
@@ -1653,7 +1668,7 @@ local block_state deflate_fast(s, flush)
         if (s->match_length >= MIN_MATCH) {
             check_match(s, s->strstart, s->match_start, s->match_length);
 
-            _spdf_tr_tally_dist(s, s->strstart - s->match_start,
+            _tr_tally_dist(s, s->strstart - s->match_start,
                            s->match_length - MIN_MATCH, bflush);
 
             s->lookahead -= s->match_length;
@@ -1690,7 +1705,7 @@ local block_state deflate_fast(s, flush)
         } else {
             /* No match, output a literal byte */
             Tracevv((stderr,"%c", s->window[s->strstart]));
-            _spdf_tr_tally_lit (s, s->window[s->strstart], bflush);
+            _tr_tally_lit (s, s->window[s->strstart], bflush);
             s->lookahead--;
             s->strstart++;
         }
@@ -1733,6 +1748,7 @@ local block_state deflate_slow(s, flush)
             }
             if (s->lookahead == 0) break; /* flush the current block */
         }
+
         /* Insert the string window[strstart .. strstart+2] in the
          * dictionary, and set hash_head to the head of the hash chain:
          */
@@ -1740,10 +1756,12 @@ local block_state deflate_slow(s, flush)
         if (s->lookahead >= MIN_MATCH) {
             INSERT_STRING(s, s->strstart, hash_head);
         }
+
         /* Find the longest match, discarding those <= prev_length.
          */
         s->prev_length = s->match_length, s->prev_match = s->match_start;
         s->match_length = MIN_MATCH-1;
+
         if (hash_head != NIL && s->prev_length < s->max_lazy_match &&
             s->strstart - hash_head <= MAX_DIST(s)) {
             /* To simplify the code, we prevent matches with the string
@@ -1752,12 +1770,14 @@ local block_state deflate_slow(s, flush)
              */
             s->match_length = longest_match (s, hash_head);
             /* longest_match() sets match_start */
+
             if (s->match_length <= 5 && (s->strategy == Z_FILTERED
 #if TOO_FAR <= 32767
                 || (s->match_length == MIN_MATCH &&
                     s->strstart - s->match_start > TOO_FAR)
 #endif
                 )) {
+
                 /* If prev_match is also MIN_MATCH, match_start is garbage
                  * but we will ignore the current match anyway.
                  */
@@ -1770,9 +1790,12 @@ local block_state deflate_slow(s, flush)
         if (s->prev_length >= MIN_MATCH && s->match_length <= s->prev_length) {
             uInt max_insert = s->strstart + s->lookahead - MIN_MATCH;
             /* Do not insert strings in hash table beyond this. */
+
             check_match(s, s->strstart-1, s->prev_match, s->prev_length);
-            _spdf_tr_tally_dist(s, s->strstart -1 - s->prev_match,
+
+            _tr_tally_dist(s, s->strstart -1 - s->prev_match,
                            s->prev_length - MIN_MATCH, bflush);
+
             /* Insert in hash table all strings up to the end of the match.
              * strstart-1 and strstart are already inserted. If there is not
              * enough lookahead, the last two strings are not inserted in
@@ -1790,13 +1813,14 @@ local block_state deflate_slow(s, flush)
             s->strstart++;
 
             if (bflush) FLUSH_BLOCK(s, 0);
+
         } else if (s->match_available) {
             /* If there was no match at the previous position, output a
              * single literal. If there was a match but the current match
              * is longer, truncate the previous match to a single literal.
              */
             Tracevv((stderr,"%c", s->window[s->strstart-1]));
-            _spdf_tr_tally_lit(s, s->window[s->strstart-1], bflush);
+            _tr_tally_lit(s, s->window[s->strstart-1], bflush);
             if (bflush) {
                 FLUSH_BLOCK_ONLY(s, 0);
             }
@@ -1815,7 +1839,7 @@ local block_state deflate_slow(s, flush)
     Assert (flush != Z_NO_FLUSH, "no flush?");
     if (s->match_available) {
         Tracevv((stderr,"%c", s->window[s->strstart-1]));
-        _spdf_tr_tally_lit(s, s->window[s->strstart-1], bflush);
+        _tr_tally_lit(s, s->window[s->strstart-1], bflush);
         s->match_available = 0;
     }
     s->insert = s->strstart < MIN_MATCH-1 ? s->strstart : MIN_MATCH-1;
@@ -1879,7 +1903,7 @@ local block_state deflate_rle(s, flush)
         if (s->match_length >= MIN_MATCH) {
             check_match(s, s->strstart, s->strstart - 1, s->match_length);
 
-            _spdf_tr_tally_dist(s, 1, s->match_length - MIN_MATCH, bflush);
+            _tr_tally_dist(s, 1, s->match_length - MIN_MATCH, bflush);
 
             s->lookahead -= s->match_length;
             s->strstart += s->match_length;
@@ -1887,7 +1911,7 @@ local block_state deflate_rle(s, flush)
         } else {
             /* No match, output a literal byte */
             Tracevv((stderr,"%c", s->window[s->strstart]));
-            _spdf_tr_tally_lit (s, s->window[s->strstart], bflush);
+            _tr_tally_lit (s, s->window[s->strstart], bflush);
             s->lookahead--;
             s->strstart++;
         }
@@ -1927,7 +1951,7 @@ local block_state deflate_huff(s, flush)
         /* Output a literal byte */
         s->match_length = 0;
         Tracevv((stderr,"%c", s->window[s->strstart]));
-        _spdf_tr_tally_lit (s, s->window[s->strstart], bflush);
+        _tr_tally_lit (s, s->window[s->strstart], bflush);
         s->lookahead--;
         s->strstart++;
         if (bflush) FLUSH_BLOCK(s, 0);
