@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -1042,9 +1042,12 @@ if (STRINGdataType(varDataType)) {
     *(((char *) pad)+0) = (char) DEFAULT_CHAR_PADVALUE;
     *(((char *) pad)+1) = (char) '\0';
   } else {
+    long numBytes = (long) UTF8StrLength ((unsigned char *)pad);
     iy = -1;
-    for (ix = 0; ix < (int) varNumElements; ++ix)
-      if (!Printable(*(((char *) pad)+ix))) *(((char *) pad)+ix) = '.';
+    if (numBytes == varNumElements) {
+      for (ix = 0; ix < (int) varNumElements; ++ix)
+        if (!Printable(*(((char *) pad)+ix))) *(((char *) pad)+ix) = '.';
+    }
     for (ix = (varNumElements-1); ix >= 0; --ix) {
       if (*(((char *) pad)+ix) != ' ') {
         iy = ix;
