@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -241,6 +241,11 @@ char *argV[];
    }
    else
      strcpyX (ilhFile, "cdfedit.ilh", MAX_ILHFILE_LEN);
+#if defined(linux)
+   /* Set it to VT100 to eleminate the strange behaviour by BS & DELA key on
+      long value/tring, e.g., an INT8, on xterm|xterm-256color terminal type */
+   setenv ("TERM", "vt100", 1);
+#endif
    InitializeScreen ();
    /***************************************************************************
    * Edit CDF(s).
